@@ -1,21 +1,15 @@
 /*
-** Copyright (C) 2003-2011 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (c) 2003-2016, Erik de Castro Lopo <erikd@mega-nerd.com>
+** All rights reserved.
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+** This code is released under 2-clause BSD license. Please see the
+** file at : https://github.com/libsndfile/libsamplerate/blob/master/COPYING
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -49,16 +43,19 @@ main (void)
 	for (k = 0 ; k < ARRAY_LEN (src_ratios) ; k++)
 		callback_test (SRC_LINEAR, src_ratios [k]) ;
 
+#ifdef ENABLE_SINC_FAST_CONVERTER
 	puts ("    Sinc interpolator :") ;
 	for (k = 0 ; k < ARRAY_LEN (src_ratios) ; k++)
 		callback_test (SRC_SINC_FASTEST, src_ratios [k]) ;
-
+#endif
 	puts ("") ;
 
 	puts ("    End of stream test :") ;
 	end_of_stream_test (SRC_ZERO_ORDER_HOLD) ;
 	end_of_stream_test (SRC_LINEAR) ;
+#ifdef ENABLE_SINC_FAST_CONVERTER
 	end_of_stream_test (SRC_SINC_FASTEST) ;
+#endif
 
 	puts ("") ;
 	return 0 ;
@@ -135,7 +132,7 @@ callback_test (int converter, double src_ratio)
 		exit (1) ;
 		} ;
 
-	src_state = src_delete (src_state) ;
+	src_delete (src_state) ;
 
 	if (fabs (read_total / src_ratio - ARRAY_LEN (test_callback_data.data)) > 2.0)
 	{	printf ("\n\nLine %d : input / output length mismatch.\n\n", __LINE__) ;
@@ -230,7 +227,7 @@ end_of_stream_test (int converter)
 		exit (1) ;
 		} ;
 
-	src_state = src_delete (src_state) ;
+	src_delete (src_state) ;
 
 	if (test_callback_data.end_of_data == 0)
 	{	printf ("\n\nLine %d : test_callback_data.end_of_data should not be 0."
