@@ -1,21 +1,15 @@
 /*
-** Copyright (C) 2002-2008 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (c) 2002-2016, Erik de Castro Lopo <erikd@mega-nerd.com>
+** All rights reserved.
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+** This code is released under 2-clause BSD license. Please see the
+** file at : https://github.com/libsndfile/libsamplerate/blob/master/COPYING
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -39,11 +33,15 @@ main (void)
 
 	process_reset_test (SRC_ZERO_ORDER_HOLD) ;
 	process_reset_test (SRC_LINEAR) ;
+#ifdef ENABLE_SINC_FAST_CONVERTER
 	process_reset_test (SRC_SINC_FASTEST) ;
+#endif
 
 	callback_reset_test (SRC_ZERO_ORDER_HOLD) ;
 	callback_reset_test (SRC_LINEAR) ;
+#ifdef ENABLE_SINC_FAST_CONVERTER
 	callback_reset_test (SRC_SINC_FASTEST) ;
+#endif
 
 	puts ("") ;
 
